summaryrefslogtreecommitdiff
path: root/qutebrowser/utils/urlutils.py
diff options
context:
space:
mode:
authorJethro Cao <jethrocao@gmail.com>2020-06-17 17:51:18 -0400
committerJethro Cao <jethrocao@gmail.com>2020-06-17 17:51:18 -0400
commita596435586ed7d8cb857fb5715297e2476d511fe (patch)
tree6a4ba191bcaf79cbc39d7491f3b9bd048bd37c39 /qutebrowser/utils/urlutils.py
parent140537522b621a7f926bff46c10b46de4b508ec6 (diff)
downloadqutebrowser-a596435586ed7d8cb857fb5715297e2476d511fe.tar.gz
qutebrowser-a596435586ed7d8cb857fb5715297e2476d511fe.zip
Rename new auto_search mode for less ambiguity
* no-url-scheme -> schemeless * improve message to log.url.debug
Diffstat (limited to 'qutebrowser/utils/urlutils.py')
-rw-r--r--qutebrowser/utils/urlutils.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/qutebrowser/utils/urlutils.py b/qutebrowser/utils/urlutils.py
index eee317e72..1aeaf59e2 100644
--- a/qutebrowser/utils/urlutils.py
+++ b/qutebrowser/utils/urlutils.py
@@ -288,9 +288,9 @@ def is_url(urlstr: str) -> bool:
# URLs with explicit schemes are always URLs
log.url.debug("Contains explicit scheme")
url = True
- elif autosearch == 'no-url-scheme' and not _has_explicit_scheme(qurl):
- # When autosearch=no-url-scheme, URLs must contain schemes to be valid
- log.url.debug("No scheme in URL while using no-url-scheme.")
+ elif autosearch == 'schemeless' and not _has_explicit_scheme(qurl):
+ # When autosearch=schemeless, URLs must contain schemes to be valid
+ log.url.debug("No explicit scheme in given URL, treating as non-URL")
url = False
elif qurl_userinput.host() in ['localhost', '127.0.0.1', '::1']:
log.url.debug("Is localhost.")